Type: Package
Package: altdoc
Title: Package Documentation Websites with 'Quarto', 'Docsify',
        'Docute', or 'MkDocs'
Version: 0.4.0
Authors@R: 
    c(person(given = "Etienne",
             family = "Bacher",
             role = c("aut", "cre", "cph"),
             email = "etienne.bacher@protonmail.com"),
      person(given = "Vincent",
             family = "Arel-Bundock",
             role = "aut",
             email = "vincent.arel-bundock@umontreal.ca",
             comment = c(ORCID = "0000-0003-2042-7063"))
    )
Description: This is a simple and powerful package to create, render, preview, 
    and deploy documentation websites for 'R' packages. It is a lightweight and 
    flexible alternative to 'pkgdown', with support for many documentation 
    generators, including 'Quarto', 'Docute', 'Docsify', and 'MkDocs'.
License: MIT + file LICENSE
URL: https://altdoc.etiennebacher.com,
        https://github.com/etiennebacher/altdoc
BugReports: https://github.com/etiennebacher/altdoc/issues
Imports: cli, desc, evaluate, fs, quarto, tools, utils
Suggests: covr, digest, downlit, future, future.apply, knitr, servr,
        spelling, testthat (>= 3.0.0), usethis, withr, yaml
Config/testthat/edition: 3
Encoding: UTF-8
LazyData: true
Roxygen: list(markdown = TRUE)
RoxygenNote: 7.3.2
Language: en-US
VignetteBuilder: knitr
Author: Etienne Bacher [aut, cre, cph],
  Vincent Arel-Bundock [aut] (<https://orcid.org/0000-0003-2042-7063>)
Maintainer: Etienne Bacher <etienne.bacher@protonmail.com>
Built: R 4.4.1; ; 2024-07-26 14:44:30 UTC; unix
