---
title: "Analysing Longitudinal or Panel Data"
author: Etienne Bacher
date: 01-01-1970
output: 
  rmarkdown::html_vignette: default
  rmarkdown::pdf_document:
    engine: xelatex
vignette: >
  %\VignetteIndexEntry{Analysing Longitudinal or Panel Data}
  \usepackage[utf8]{inputenc}
  %\VignetteEngine{knitr::rmarkdown}
editor_options: 
  chunk_output_type: console
---

Hello this is a vignette.

Here's some code:

```{r}
print(mtcars)
```

