% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/funs.R
\name{foobar}
\alias{foobar}
\title{Some function}
\keyword{internal}
\usage{
  foo(x)
}
\arguments{
  \item{x}{hello there}
}
\description{
  foo
}
\examples{
  print(a)
}
